@@ -104,9 +104,21 @@ class SlappResponseObject:
         return [player_dict["Item1"] for player_dict in self.matched_players_for_teams.get(team_guid.__str__(), [])
                 if player_dict and player_dict.get("Item1") and (player_dict["Item2"] or include_ex_players)]
 
-    def get_teams_for_player(self, p: Player) -> List[Team]:
+    def get_team(self, team_id: Union[str, UUID]) -> Team:
         from slapp_py.core_classes.builtins import NoTeam, UnknownTeam
-        return list(map(lambda t: self.known_teams.get(t, UnknownTeam) if t != NoTeam.guid else NoTeam, p.teams))
+        if isinstance(team_id, UUID):
+            t_str = team_id.__str__()
+        elif isinstance(team_id, str):
+            t_str = team_id
+        elif team_id is None:
+            return NoTeam
+        else:
+            assert False, f"Don't know what {team_id} is"
+
+        return NoTeam if t_str == NoTeam.guid.__str__() else self.known_teams.get(t_str, UnknownTeam)
+
+    def get_teams_for_player(self, p: Player) -> List[Team]:
+        return [self.get_team(t_uuid) for t_uuid in p.teams]
 
     def get_team_skills(self, team_guid: Union[UUID, str], include_ex_players: bool = True) -> Dict[Player, Skill]:
         """
